@@ -1,4 +1,4 @@
-;; Quail packages for inputting various European characters.
+;;; latin-alt.el --- Quail packages for inputting various European characters
 
 ;; Copyright (C) 1997 Electrotechnical Laboratory, JAPAN.
 ;; Licensed to the Free Software Foundation.
@@ -24,6 +24,10 @@
 
 ;; Author: TAKAHASHI Naoto <ntakahas@etl.go.jp>
 
+;;; Commentary:
+
+;;; Code:
+
 (require 'quail)
 
 (quail-define-package
@@ -39,7 +43,8 @@
   tilde      |    ~    | a~ -> ,Ac(B
   cedilla    |    /    | c/ -> ,Ag(B
   nordic     |    /    | d/ -> ,Ap(B   t/ -> ,A~(B   a/ -> ,Ae(B   e/ -> ,Af(B   o/ -> ,Ax(B
-  others     |   /<>   | s/ -> ,A_(B   ?/ -> ,A?(B   !/ -> ,A!(B   << -> ,A+(B   >> -> ,A;(B
+  others     |   /<>   | s/ -> ,A_(B   ?/ -> ,A?(B   !/ -> ,A!(B
+             | various | << -> ,A+(B   >> -> ,A;(B   o_ -> ,A:(B   a_ -> ,A*(B
 
 It would be natural to use comma for cedillas, but that would be
 inconvenient in practice because commas are needed very often after a
@@ -115,6 +120,8 @@ Doubling the postfix separates the letter and postfix: e.g. a'' -> a'
  ("!/" ?,A!(B)
  ("<<" ?,A+(B)
  (">>" ?,A;(B)
+ ("o_" ?,A:(B)
+ ("a_" ?,A*(B)
 
  ("A``" ["A`"])
  ("A''" ["A'"])
@@ -182,6 +189,8 @@ Doubling the postfix separates the letter and postfix: e.g. a'' -> a'
  ("!//" ["!/"])
  ("<<<" ["<<"])
  (">>>" [">>"])
+ ("o__" ["o_"])
+ ("a__" ["a_"])
  )
 
 (quail-define-package
@@ -925,7 +934,7 @@ Doubling the postfix separates the letter and postfix: e.g. aee -> ae
  "Esperanto input method with postfix modifiers
 
 A following ^ or x will produce an accented character,
-e.g. c^ -> ,Cf(B, gx -> ,Cx(B, u^ -> ,C}(B.
+e.g. c^ -> ,Cf(B   gx -> ,Cx(B   u^ -> ,C}(B.
 
 Doubling the postfix separates the letter and postfix,
 e.g. a'' -> a'.
@@ -1011,7 +1020,7 @@ OEE -> OE
  "French (Fran,Ag(Bais) input method with postfix modifiers
 
 ` pour grave, ' pour aigu, ^ pour circonflexe, et \" pour tr,Ai(Bma.
-Par exemple: a` -> ,A`(B, e' -> ,Ai(B.
+Par exemple: a` -> ,A`(B   e' -> ,Ai(B.
 
 ,AG(B, ,A+(B, et ,A;(B sont produits par C/, <<, et >>.
 
@@ -1180,37 +1189,71 @@ Doubling the postfix separates the letter and postfix: e.g. a'' -> a'
  "italian-alt-postfix" "Latin-1" "IT<" t
  "Italian (Italiano) input method with postfix modifiers
 
-A` -> ,A@(B
-E` -> ,AH(B
-I` -> ,AL(B
-O` -> ,AR(B
-U` -> ,AY(B
+a' -> ,Aa(B    A' -> ,AA(B    a` -> ,A`(B    A` -> ,A@(B    i^ -> ,An(B    << -> ,A+(B
+e' -> ,Ai(B    E' -> ,AI(B    e` -> ,Ah(B    E` -> ,AH(B    I^ -> ,AN(B    >> -> ,A;(B
+i' -> ,Am(B    I' -> ,AM(B    i` -> ,Al(B    I` -> ,AL(B               o_ -> ,A:(B
+o' -> ,As(B    O' -> ,AS(B    o` -> ,Ar(B    O` -> ,AR(B               a_ -> ,A*(B
+u' -> ,Az(B    U' -> ,AZ(B    u` -> ,Ay(B    U` -> ,AY(B    
+
+This method is for purists who like accents the old way.
 
 Doubling the postfix separates the letter and postfix: e.g. a`` -> a`
 " nil t nil nil nil nil nil nil nil nil t)
 
 (quail-define-rules
  ("A`" ?,A@(B)
+ ("A'" ?,AA(B)
  ("a`" ?,A`(B)
+ ("a'" ?,Aa(B)
  ("E`" ?,AH(B)
+ ("E'" ?,AI(B)
  ("e`" ?,Ah(B)
+ ("e'" ?,Ai(B)
  ("I`" ?,AL(B)
  ("i`" ?,Al(B)
+ ("I'" ?,AM(B)
+ ("i'" ?,Am(B)
+ ("I^" ?,AN(B)
+ ("i^" ?,An(B)
  ("O`" ?,AR(B)
  ("o`" ?,Ar(B)
+ ("O'" ?,AS(B)
+ ("o'" ?,As(B)
  ("U`" ?,AY(B)
  ("u`" ?,Ay(B)
+ ("U'" ?,AZ(B)
+ ("u'" ?,Az(B)
+ ("<<" ?,A+(B)
+ (">>" ?,A;(B)
+ ("o_" ?,A:(B)
+ ("a_" ?,A*(B)
 
  ("A``" ["A`"])
+ ("A''" ["A'"])
  ("a``" ["a`"])
+ ("a''" ["a'"])
  ("E``" ["E`"])
+ ("E''" ["E'"])
  ("e``" ["e`"])
+ ("e''" ["e'"])
  ("I``" ["I`"])
  ("i``" ["i`"])
+ ("I''" ["I'"])
+ ("i''" ["i'"])
+ ("I^^" ["I^"])
+ ("i^^" ["i^"])
  ("O``" ["O`"])
  ("o``" ["o`"])
+ ("O''" ["O'"])
+ ("o''" ["o'"])
  ("U``" ["U`"])
  ("u``" ["u`"])
+ ("U''" ["U'"])
+ ("u''" ["u'"])
+ ("<<<" ["<<"])
+ (">>>" [">>"])
+ ("o__" ["o_"])
+ ("a__" ["a_"])
  )
 
 (quail-define-package
@@ -1254,7 +1297,7 @@ o\" -> ,Av(B
 e' -> ,Ai(B
 
 Doubling the postfix separates the letter and postfix:
-aee -> ae, o\"\" -> o\", etc.
+aee -> ae   o\"\" -> o\"   etc.
 " nil t nil nil nil nil nil nil nil nil t)
 
 (quail-define-rules
@@ -1299,7 +1342,7 @@ N~ -> ,AQ(B
 ?/ -> ,A?(B
 
 Doubling the postfix separates the letter and postfix:
-a'' -> a', n~~ -> n~, etc.
+a'' -> a'   n~~ -> n~, etc.
 " nil t nil nil nil nil nil nil nil nil t)
 
 (quail-define-rules
@@ -1362,8 +1405,11 @@ Doubling the postfix separates the letter and postfix: e.g. aee -> ae
  )
 
 (quail-define-package
- "turkish-alt-postfix" "Latin-3" "TR<" t
- "Turkish (T,C|(Brk,Cg(Be) input method with postfix modifiers
+ "turkish-latin-3-alt-postfix" "Latin-3" "TR3<<" t
+ "Turkish (T,C|(Brk,Cg(Be) input method with postfix modifiers.
+
+This is for those who use Latin-3 (ISO-8859-3) for Turkish.  If you
+use Latin-5 (ISO-8859-9), you should use \"turkish-alt-postfix\" instead.
 
 Note for I, ,C9(B, ,C)(B, i.
 
@@ -1419,3 +1465,68 @@ Doubling the postfix separates the letter and postfix: e.g. a^^ -> a^
  ("U^^" ["U^"])
  ("u^^" ["u^"])
  )
+
+(quail-define-package
+ "turkish-alt-postfix" "Latin-5" "TR,M+(B" t
+ "Turkish (T,M|(Brk,Mg(Be) input method with postfix modifiers.
+
+This is for those who use Latin-5 (ISO-8859-9) for Turkish.  If you
+use Latin-3 (ISO-8859-3), you should use
+\"turkish-latin-3-alt-postfix\" instead.
+
+Note for I, ,M}(B, ,M](B, i.
+
+A^ -> ,MB(B
+C` -> ,MG(B
+G^ -> ,MP(B
+I  -> I
+i  -> ,M}(B
+I/ -> ,M](B
+i/ -> i
+O\" -> ,MV(B
+S` -> ,M^(B
+U\" -> ,M\(B
+U^ -> ,M[(B
+
+Doubling the postfix separates the letter and postfix: e.g. a^^ -> a^
+" nil t nil nil nil nil nil nil nil nil t)
+
+(quail-define-rules
+ ("A^" ?,MB(B)
+ ("a^" ?,Mb(B)
+ ("C`" ?,MG(B)
+ ("c`" ?,Mg(B)
+ ("G^" ?,MP(B)
+ ("g^" ?,Mp(B)
+ ("I/" ?,M](B)
+ ("i" ?,M}(B)
+ ("i/" ?i)
+ ("O\"" ?,MV(B)
+ ("o\"" ?,Cv(B)
+ ("S`" ?,M^(B)
+ ("s`" ?,M~(B)
+ ("U\"" ?,M\(B)
+ ("u\"" ?,M|(B)
+ ("U^" ?,M[(B)
+ ("u^" ?,M{(B)
+
+ ("A^^" ["A^"])
+ ("a^^" ["a^"])
+ ("C``" ["C`"])
+ ("c``" ["c`"])
+ ("G^^" ["G^"])
+ ("g^^" ["g^"])
+ ("I//" ["I/"])
+ ("i" ["i"])
+ ("i//" ["i/"])
+ ("O\"\"" ["O\""])
+ ("o\"\"" ["o\""])
+ ("S``" ["S`"])
+ ("s``" ["s`"])
+ ("U\"\"" ["U\""])
+ ("u\"\"" ["u\""])
+ ("U^^" ["U^"])
+ ("u^^" ["u^"])
+ )
+
+;;; latin-alt.el ends here
